==> haskell-contravariant-extras-0.3.5.2-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 contravariant-extras
version:              0.3.5.2
visibility:           public
id:                   contravariant-extras-0.3.5.2-FYsJj6cenYlIIafZWGK1Fy
key:                  contravariant-extras-0.3.5.2-FYsJj6cenYlIIafZWGK1Fy
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/contravariant-extras
synopsis:             Extras for the "contravariant" package
category:             Control
abi:                  f5f9c853b5f64600b0de176bf5bd30b1
exposed:              True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.ContrazipLifting Contravariant.Extras.Op
    Contravariant.Extras.Op.Contrazip

hidden-modules:       Contravariant.Extras.Prelude Contravariant.Extras.TH
import-dirs:          /usr/lib/ghc-8.10.4/site-local/contravariant-extras-0.3.5.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/contravariant-extras-0.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/contravariant-extras-0.3.5.2

hs-libraries:         HScontravariant-extras-0.3.5.2-FYsJj6cenYlIIafZWGK1Fy
depends:
    base-4.14.1.0 contravariant-1.5.3-7koBfVZf7s8G3BlROnwJJd
    template-haskell-2.16.0.0
    template-haskell-compat-v0208-0.1.5-61xQ6YVgg5YDj3UfITFO4b

haddock-interfaces:
    /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock

haddock-html:         /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-extras-0.3.5.2-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 contravariant-extras
version:              0.3.5.2
visibility:           public
id:                   contravariant-extras-0.3.5.2-9aGh0wtiuis9PGmf344MrP
key:                  contravariant-extras-0.3.5.2-9aGh0wtiuis9PGmf344MrP
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/contravariant-extras
synopsis:             Extras for the "contravariant" package
category:             Control
abi:                  ae4eac167a4517c559cdeb9c37d81aff
exposed:              True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.ContrazipLifting Contravariant.Extras.Op
    Contravariant.Extras.Op.Contrazip

hidden-modules:       Contravariant.Extras.Prelude Contravariant.Extras.TH
import-dirs:          /usr/lib/ghc-9.0.1/site-local/contravariant-extras-0.3.5.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/contravariant-extras-0.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/contravariant-extras-0.3.5.2

hs-libraries:         HScontravariant-extras-0.3.5.2-9aGh0wtiuis9PGmf344MrP
depends:
    base-4.15.0.0 contravariant-1.5.3-9uWNjFwgxFqEvI9fWPdJzP
    template-haskell-2.17.0.0
    template-haskell-compat-v0208-0.1.5-1IgKwd1L9Q2IqxpHUdR1yK

haddock-interfaces:
    /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock

haddock-html:         /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
